sqlobject.tests.test_transactions module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_transactions module

class `sqlobject.tests.test_transactions.` `SOTestSOTrans`(**kw)

  Bases: `sqlobject.main.SQLObject`

  classmethod `byName`(val, connection=None)
  `j` = so_test_so_trans
  property `name`
  `q` = so_test_so_trans
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `defaultOrder` = 'name'
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_transactions.SOTestSOTrans`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_so_trans'

`sqlobject.tests.test_transactions.` `make_listen`(signal)

`sqlobject.tests.test_transactions.` `make_watcher`()

`sqlobject.tests.test_transactions.` `test_transaction`()

`sqlobject.tests.test_transactions.` `test_transaction_commit_sync`()

`sqlobject.tests.test_transactions.` `test_transaction_delete`(close=False)

`sqlobject.tests.test_transactions.` `test_transaction_delete_with_close`()